# Autoproj::Stats

An Autoproj plugin to generate authorship/copyright statistics

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'autoproj-stats'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install autoproj-stats

## Usage

The plugin can be accessed from the autoproj command line with

~~~
autoproj help stats
~~~

In its simplest form, it's going to compute authorship information for all
supported VCS types in the autoproj installation, and display summary
information at the end.

~~~
autoproj stats
~~~

The statistics can be saved in a text file with --save

~~~
autoproj stats --save=stats.txt
~~~

The first thing you may want to improve is sanitizing author name(s). This is
done by providing a YAML config file with an 'aliases' section. The method is
usually to comb through the list of names in the summary generated by autoproj
stats and replace dummy names by actual ones.

~~~
aliases:
    Name As Reported By Autoproj Stats: Actual Name
~~~

This config file (let's call it stats.yml) can then be passed to autoproj stats
with the --config option

~~~
autoproj stats --config=stats.yml
~~~

Then, you probably want to add affiliation information (a.k.a. copyright
assignation). The simplest is to provide an institution/copyright holder name
per author name:

~~~
affiliations:
    Author Name: Company Name
~~~

However, some authors change affiliations over time, in which case you provide a
list of company and start dates:

~~~
affiliations:
    Author Name:
    - [Company1, 2008-02-01]
    - [Company2, 2012-03-01]
~~~

Finally, you can provide per-package license information. No way to give
fine-grained stuff there.

~~~
licenses:
    package_name: License Name
~~~

## Development

After checking out the repo, run `bundle install` to install dependencies. Then, run `rake test` to run the tests.

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/doudou/autoproj-stats.

## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

